==> hippoagentsdk-0.1.3-sources.jar: com/hippoagent/adapters/TagsAdapter.java <==
package com.hippoagent.adapters;

import android.content.Context;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.hippoagent.R;
import com.hippoagent.model.ContentValue;

import java.util.ArrayList;

/**
 * Created by gurmail on 2019-12-05.
 *
 * @author gurmail
 */
public class TagsAdapter extends RecyclerView.Adapter<TagsAdapter.ViewHolder> {

    public ArrayList<ContentValue> arrayList = new ArrayList<>();
    private Context mContext;

    public TagsAdapter(ArrayList<ContentValue> arrayList) {
        this.arrayList = arrayList;
    }

    @NonNull
    @Override
    public ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        mContext = viewGroup.getContext();
        return new ViewHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.item_tag_view, viewGroup, false));
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder viewHolder, int i) {
        viewHolder.tagView.setText(arrayList.get(i).getBtnTitle());
    }

    @Override
    public int getItemCount() {
        return arrayList.size();
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        private TextView tagView;
        public ViewHolder(@NonNull View itemView) {
            super(itemView);
            tagView = itemView.findViewById(R.id.tagView);
        }
    }
}

==> hippoagentsdk-3.0.5.1-sources.jar: com/hippoagent/adapters/TagsAdapter.java <==
package com.hippoagent.adapters;

import android.content.Context;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.hippoagent.R;
import com.hippoagent.model.ContentValue;

import java.util.ArrayList;

/**
 * Created by gurmail on 2019-12-05.
 *
 * @author gurmail
 */
public class TagsAdapter extends RecyclerView.Adapter<TagsAdapter.ViewHolder> {

    public ArrayList<ContentValue> arrayList = new ArrayList<>();
    private Context mContext;
    private OnTagClicked onTagClicked;

    public TagsAdapter(ArrayList<ContentValue> arrayList) {
        this.arrayList = arrayList;
    }

    @NonNull
    @Override
    public ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        mContext = viewGroup.getContext();
        return new ViewHolder(LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.item_tag_view, viewGroup, false));
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder viewHolder, int i) {
        viewHolder.tagView.setText(arrayList.get(i).getBtnTitle());
    }

    @Override
    public int getItemCount() {
        return arrayList.size();
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        private TextView tagView;
        public ViewHolder(@NonNull View itemView) {
            super(itemView);
            tagView = itemView.findViewById(R.id.tagView);
            tagView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if(onTagClicked != null) {
                        onTagClicked.onClick(getAdapterPosition(), arrayList.get(getAdapterPosition()));
                    }
                }
            });
        }
    }

    public interface OnTagClicked {
        void onClick(int position, ContentValue contentValue);
    }
}
